@@ -1,5 +1,5 @@
 package Weather::OpenWeatherMap;
-$Weather::OpenWeatherMap::VERSION = '0.001003';
+$Weather::OpenWeatherMap::VERSION = '0.001005';
 use strictures 1;
 use Carp;
 
@@ -8,9 +8,18 @@ use LWP::UserAgent;
 use Types::Standard -all;
 
 
+use Weather::OpenWeatherMap::Cache;
 use Weather::OpenWeatherMap::Error;
+
+
+# Full require list to make Storable retrievals comfortable:
 use Weather::OpenWeatherMap::Request;
+require Weather::OpenWeatherMap::Request::Current;
+require Weather::OpenWeatherMap::Request::Forecast;
+
 use Weather::OpenWeatherMap::Result;
+require Weather::OpenWeatherMap::Result::Current;
+require Weather::OpenWeatherMap::Result::Forecast;
 
 
 use Moo; use MooX::late;
@@ -29,6 +38,41 @@ has api_key => (
   builder   => sub { '' },
 );
 
+has cache => (
+  lazy      => 1,
+  is        => 'ro',
+  isa       => Bool,
+  builder   => sub { 0 },
+);
+
+has cache_dir => (
+  lazy      => 1,
+  is        => 'ro',
+  isa       => Maybe[Str],
+  builder   => sub { undef },
+);
+
+has cache_expiry => (
+  lazy      => 1,
+  is        => 'ro',
+  isa       => Maybe[StrictNum],
+  builder   => sub { undef },
+);
+
+has _cache => (
+  lazy      => 1,
+  is        => 'ro',
+  isa       => InstanceOf['Weather::OpenWeatherMap::Cache'],
+  builder   => sub {
+    my ($self) = @_;
+    Weather::OpenWeatherMap::Cache->new(
+      ( $self->cache_dir ?    (dir => $self->cache_dir)       : () ),
+      ( $self->cache_expiry ? (expiry => $self->cache_expiry) : () ),
+    )
+  },
+);
+
+
 has ua => (
   is        => 'ro',
   isa       => InstanceOf['LWP::UserAgent'],
@@ -52,22 +96,28 @@ sub get_weather {
       %args
   );
 
-  my $http_response = $self->ua->request( $my_request->http_request );
+  my $result;
 
-  unless ($http_response->is_success) {
-    die Weather::OpenWeatherMap::Error->new(
-      request => $my_request,
-      source  => 'http',
-      status  => $http_response->status_line,
+  if ( $self->cache && (my $cached = $self->_cache->retrieve($my_request)) ) {
+    $result = $cached->object
+  } else {
+    my $http_response = $self->ua->request( $my_request->http_request );
+
+    unless ($http_response->is_success) {
+      die Weather::OpenWeatherMap::Error->new(
+        request => $my_request,
+        source  => 'http',
+        status  => $http_response->status_line,
+      );
+    }
+
+    $result = Weather::OpenWeatherMap::Result->new_for(
+      $type =>
+        request => $my_request,
+        json    => $http_response->content
     );
   }
 
-  my $result = Weather::OpenWeatherMap::Result->new_for(
-    $type =>
-      request => $my_request,
-      json    => $http_response->content
-  );
-
   unless ($result->is_success) {
     die Weather::OpenWeatherMap::Error->new(
       request => $my_request,
@@ -76,6 +126,8 @@ sub get_weather {
     )
   }
 
+  $self->_cache->cache($result) if $self->cache;
+
   $result
 }
 
@@ -132,6 +184,9 @@ L<Weather::OpenWeatherMap::Request> & L<Weather::OpenWeatherMap::Result>
 classes can be used to create appropriate L<HTTP::Request> instances and parse
 responses from non-blocking HTTP clients.
 
+See L<POEx::Weather::OpenWeatherMap> for a non-blocking implementation using
+the L<POE> ecosystem.
+
 =head2 ATTRIBUTES
 
 =head3 api_key
@@ -140,6 +195,23 @@ Your L<OpenWeatherMap|http://www.openweathermap.org/> API key.
 
 (See L<http://www.openweathermap.org/api> to register for free.)
 
+=head3 cache
+
+A boolean value indicating whether successful results should be cached to
+disk via L<Weather::OpenWeatherMap::Cache>.
+
+Defaults to false. This may change in a future release.
+
+=head3 cache_dir
+
+The directory in which cache files are saved. The default may be fine; see
+L<Weather::OpenWeatherMap::Cache>.
+
+=head3 cache_expiry
+
+The duration (in seconds) for which cache files are considered valid; see
+L<Weather::OpenWeatherMap::Cache>.
+
 =head3 ua
 
 The L<LWP::UserAgent> instance used to issue HTTP requests; can be used to
@@ -194,6 +266,10 @@ L<Weather::OpenWeatherMap::Request::Forecast>), in which case C<< days
 Any extra arguments are passed to the constructor for the appropriate Request
 subclass; see L<Weather::OpenWeatherMap::Request>.
 
+=head1 SEE ALSO
+
+L<POEx::Weather::OpenWeatherMap>
+
 =head1 AUTHOR
 
 Jon Portnoy <avenj@cobaltirc.org>
